/*
 * xrmoptions.h
 *	Standard XrmOptionDescRec list for wlib resources.
 *
 * Copyright (C) 1997  Matthew D. Francey
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Authors:	Matthew D. Francey
 *		Eric A. Howe (mu@trends.net)
 **
 * $Mu: wlib/wlib/xrmoptions.h,v 1.10 $
 */
	{"-browser",	"*helpBrowser",		XrmoptionSepArg, NULL},
	{"-helpport",	"*helpCCIPort",		XrmoptionSepArg, NULL},
	{"-helptype",	"*helpType",		XrmoptionSepArg, NULL},
	{"-prefix",	"*helpPrefix",		XrmoptionSepArg, NULL},

	{"-noicon",     "*wlInstallIcon",	XrmoptionNoArg,  "False"},
	{"-installicon","*wlInstallIcon",	XrmoptionNoArg,  "True"},

	{"-coloricon",	"*wlUseColorIcon",	XrmoptionNoArg,  "True"},
	{"-monoicon",	"*wlUseColorIcon",	XrmoptionNoArg,  "False"},
	{"-nocoloricon","*wlUseColorIcon",	XrmoptionNoArg,  "False"},
